@@ -41,6 +41,9 @@ FAILEDOPERATION_CLUSTERSTATE = 'FailedOperation.ClusterState'
 # The version of the cluster node is too old.
 FAILEDOPERATION_CLUSTERUPGRADENODEVERSION = 'FailedOperation.ClusterUpgradeNodeVersion'
 
+# Internal client error.
+FAILEDOPERATION_COMPONENTCLIENTCOMMON = 'FailedOperation.ComponentClientCommon'
+
 # Internal HTTP client error.
 FAILEDOPERATION_COMPONENTCLIENTHTTP = 'FailedOperation.ComponentClientHttp'
 
@@ -125,6 +128,9 @@ FAILEDOPERATION_RECORDNOTFOUND = 'FailedOperation.RecordNotFound'
 # A same task is in progress.
 FAILEDOPERATION_TASKALREADYRUNNING = 'FailedOperation.TaskAlreadyRunning'
 
+# 
+FAILEDOPERATION_TASKLIFESTATEERROR = 'FailedOperation.TaskLifeStateError'
+
 # Query failed.
 FAILEDOPERATION_TRADECOMMON = 'FailedOperation.TradeCommon'
 
